@@ -15,18 +15,14 @@ from .base import ClosableResponse, EmptyResponse, Header, Request
 from .context import set_context
 from .deadline import Deadline
 from .priority import Priority
-from .request_sender import RequestSender
+from .transport import Transport
 from .utils import substitute_path_parameters
 
 logger = logging.getLogger(__package__)
 
 
-class AioHttpRequestSender(RequestSender):
-    __slots__ = (
-        "_client_session",
-        "_network_errors_code",
-        "_buffer_payload",
-    )
+class AioHttpTransport(Transport):
+    __slots__ = ("_client_session", "_network_errors_code", "_buffer_payload")
 
     def __init__(
         self,
@@ -39,12 +35,12 @@ class AioHttpRequestSender(RequestSender):
         self._network_errors_code = network_errors_code
         self._buffer_payload = buffer_payload
 
-    async def send(self, endpoint_url: yarl.URL, request: Request, timeout: float) -> ClosableResponse:
-        if not endpoint_url.is_absolute():
+    async def send(self, endpoint: yarl.URL, request: Request, timeout: float) -> ClosableResponse:
+        if not endpoint.is_absolute():
             raise RuntimeError("Base url should be absolute")
 
         method = request.method
-        url = substitute_path_parameters(endpoint_url.join(request.url), request.path_parameters)
+        url = endpoint.join(substitute_path_parameters(request.url, request.path_parameters))
         headers = request.headers
         body = request.body
 
